package adminkindboxreq

import (
	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box_req"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	richerror "git.gocasts.ir/ebhomengo/niki/pkg/rich_error"
	validation "github.com/go-ozzo/ozzo-validation/v4"
)

func (v Validator) ValidateAddRequest(req param.KindBoxReqAddRequest) (map[string]string, error) {
	const op = "adminkindboxreq.ValidateAddRequest"

	if err := validation.ValidateStruct(&req,

		validation.Field(&req.CountRequested, validation.Required, validation.Min(MinKindBoxReq), validation.Max(MaxKindBoxReq)),

		validation.Field(&req.BenefactorID,
			validation.Required,
			validation.By(v.doesBenefactorExist(req.BenefactorID))),

		validation.Field(&req.TypeID,
			validation.Required,
			validation.By(v.doesTypeExist(req.TypeID))),
	); err != nil {
		fieldErrors := make(map[string]string)

		errV, ok := err.(validation.Errors)
		if ok {
			for key, value := range errV {
				if value != nil {
					fieldErrors[key] = value.Error()
				}
			}
		}

		return fieldErrors, richerror.New(op).
			WithMessage(errmsg.ErrorMsgInvalidInput).
			WithKind(richerror.KindInvalid).
			WithMeta(map[string]interface{}{"req": req}).
			WithErr(err)
	}

	return nil, nil
}
